import { _ as _objectWithoutPropertiesLoose } from './index.esm2.js';
import React__default from 'react';
import PropTypes from 'prop-types';
import RichTextEditor from 'react-rte';
import { jsxs, jsx } from 'react/jsx-runtime';
import '@qubejs/core';
import 'react-dom';
import 'react-google-recaptcha';
import 'react-router-dom';

const _excluded = ["label", "className", "formatter", "value", "error", "errorMessage"];
function getText(html) {
  var divContainer = document.createElement('div');
  divContainer.innerHTML = html;
  return divContainer.textContent || divContainer.innerText || '';
}
class BasicRTE extends React__default.Component {
  constructor() {
    super();
    this.state = {
      value: RichTextEditor.createEmptyValue(),
      focused: false,
      hasChanged: false
    };
    this.handleFocus = this.handleFocus.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
    this.handleOnChange = this.handleOnChange.bind(this);
  }
  handleOnChange(value) {
    const html = value.toString('html');
    const hasText = getText(html);
    this.setState({
      value: value,
      hasChanged: true
    });
    const {
      onChange
    } = this.props;
    onChange && onChange({
      value: hasText && html
    });
  }
  componentDidMount() {
    if (this.props.value) {
      this.setState({
        value: RichTextEditor.createValueFromString(this.props.value, 'html')
      });
    }
  }
  componentDidUpdate(prevProps) {
    if (!this.state.focused && prevProps.value !== this.props.value) {
      this.setState({
        value: RichTextEditor.createValueFromString(this.props.value, 'html')
      });
    }
  }
  handleFocus() {
    this.setState({
      focused: true
    });
  }
  handleBlur() {
    this.props;
    this.setState({
      focused: false
    });
  }
  render() {
    const {
      focused
    } = this.state;
    const _this$props = this.props,
      {
        label,
        className = '',
        error,
        errorMessage
      } = _this$props;
      _objectWithoutPropertiesLoose(_this$props, _excluded);
    return /*#__PURE__*/jsxs("div", {
      className: `sq-basic-rte${focused ? ' sq-basic-rte--focused' : ''} ${className}`,
      children: [label && /*#__PURE__*/jsx("label", {
        htmlFor: "",
        children: label
      }), /*#__PURE__*/jsx(RichTextEditor, {
        onFocus: this.handleFocus,
        onBlur: this.handleBlur,
        onChange: this.handleOnChange,
        className: `sq-basic-rte__editor`,
        defaultValue: this.props.value,
        value: this.state.value
      }), !focused && error && /*#__PURE__*/jsx("div", {
        className: "sq-textarea-field--error",
        children: errorMessage
      })]
    });
  }
}
BasicRTE.propTypes = {
  errorMessage: PropTypes.string,
  className: PropTypes.string,
  value: PropTypes.any,
  formatter: PropTypes.object,
  onChange: PropTypes.func,
  onKeyPress: PropTypes.func,
  onBlur: PropTypes.func
};

export { BasicRTE as default };
